// define a namespace to hold our widget specific functions,
// avoid polluting the global namespace
var stopwatch = stopwatch || {
	// milliseconds between ticks
	interval: 50,
	// supported languages
	languages: new Array("en", "ru")
}

stopwatch.pad = function(num) {
	if (num < 10) return "0" + num
	return num
}

// display update
stopwatch.update = function(elapsed) {
	stopwatch.elapsed = elapsed
	var secs = Math.floor(elapsed / 1000)
	var mins = Math.floor(secs / 60)
	var secs = secs % 60
	var csecs = Math.floor(elapsed % 1000 / 10)
	document.getElementById('display').value = stopwatch.pad(mins)
		+ ":" + stopwatch.pad(secs) + "." + stopwatch.pad(csecs)
}

// on setInterval event
stopwatch.onTimer = function() {
	if (stopwatch.started) {
		curTime = new Date()
		stopwatch.update(curTime.valueOf() - stopwatch.startTime.valueOf())
	}
}

stopwatch.stop = function() {
	stopwatch.started = false
	document.getElementById('startButton').value = lang.start
	window.clearInterval(stopwatch.timerInterval)
}

// on start/stop button
stopwatch.startButtonClick = function(e) {
	if (stopwatch.started) {
		stopwatch.stop();
		player_call();
	} else {
		//arrive();
		stopwatch.started = true
		document.getElementById('startButton').value = lang.stop
		curTime = new Date()
		stopwatch.startTime = new Date(curTime.valueOf() - stopwatch.elapsed)
		stopwatch.timerInterval = window.setInterval(stopwatch.onTimer, stopwatch.interval);
		player_call();
	}
}

// on reset button
stopwatch.resetButtonClick = function(e) {
	stopwatch.stop();
	player_call();
	stopwatch.update(0);
}

// loads the javascript file dynamically
stopwatch.loadScript = function(url) {
  var script = document.createElement('script')
  script.setAttribute('type', 'text/javascript')
  script.setAttribute('src', url)
  script.setAttribute("language", "javascript");
  script.onload = function (ev) { stopwatch.onLoad(ev) }
  document.documentElement.firstChild.appendChild(script)
}

// preinitialize the widget
stopwatch.preLoad = function(e) {
	// load the language
	var langCode = stopwatch.languages[0]
	for (var i = 1; i < stopwatch.languages.length; i++)
		if (stopwatch.languages[i] == window.navigator.language) {
			langCode = stopwatch.languages[i]
			break
		}
	stopwatch.loadScript("script/lang_" + langCode + ".js")
}

// initialize the widget
stopwatch.onLoad = function(e) {
	stopwatch.started = false
	stopwatch.update(0)
	
	// init messages
	document.getElementById('closeButton').value = lang.close
	document.getElementById('startButton').value = lang.start
	document.getElementById('resetButton').value = lang.reset
	document.title = lang.title

    // add behavior to the start button
    document.getElementById('startButton').addEventListener('click', function(ev) {
		stopwatch.startButtonClick()
	}, false)
    // add behavior to the close button
    document.getElementById('closeButton').addEventListener('click', function(ev) {
		window.close()
	}, false)
    document.getElementById('resetButton').addEventListener('click', function(ev) {
		stopwatch.resetButtonClick()
	}, false)
}

window.addEventListener('load', function(ev) {
	stopwatch.preLoad(ev)
}, false)
